@@ -37,6 +37,7 @@ typedef enum {
 
 	E_CONTACT_UID = 1,     	 /* string field */
 	E_CONTACT_FILE_AS,     	 /* string field */
+	E_CONTACT_BOOK_URI,      /* string field */
 
 	/* Name fields */
 	E_CONTACT_FULL_NAME,   	 /* string field */
@@ -185,6 +186,17 @@ typedef enum {
 	/* Security Fields */
 	E_CONTACT_X509_CERT,     /* structured field (EContactCert) */
 
+	/*New Fields Added to the Enum and Padding for future*/
+	
+	E_CONTACT_IM_GADUGADU_HOME_1,  /* Synthetic string field */
+	E_CONTACT_IM_GADUGADU_HOME_2,  /* Synthetic string field */
+	E_CONTACT_IM_GADUGADU_HOME_3,  /* Synthetic string field */
+	E_CONTACT_IM_GADUGADU_WORK_1,  /* Synthetic string field */
+	E_CONTACT_IM_GADUGADU_WORK_2,  /* Synthetic string field */
+	E_CONTACT_IM_GADUGADU_WORK_3,  /* Synthetic string field */
+
+	E_CONTACT_IM_GADUGADU,   /* Multi-valued */
+	
 
 	E_CONTACT_FIELD_LAST,
 	E_CONTACT_FIELD_FIRST        = E_CONTACT_UID,
@@ -210,9 +222,21 @@ typedef struct {
 	char *suffixes;
 } EContactName;
 
+typedef enum {
+	E_CONTACT_PHOTO_TYPE_INLINED,
+	E_CONTACT_PHOTO_TYPE_URI
+} EContactPhotoType;
+
 typedef struct {
-	int length;
-	char *data;
+	EContactPhotoType type;
+	union {
+		struct {
+			char *mime_type;
+			int length;
+			guchar *data;
+		} inlined;
+		char *uri;
+	} data;
 } EContactPhoto;
 
 typedef struct {
@@ -264,8 +288,8 @@ EContact*               e_contact_new_from_vcard   (const char *vcard);
 EContact*               e_contact_duplicate        (EContact *contact);
 
 gpointer                e_contact_get              (EContact *contact, EContactField field_id);
-const gpointer          e_contact_get_const        (EContact *contact, EContactField field_id);
-void                    e_contact_set              (EContact *contact, EContactField field_id, gpointer value);
+gconstpointer		e_contact_get_const        (EContact *contact, EContactField field_id);
+void                    e_contact_set              (EContact *contact, EContactField field_id, const gpointer value);
 
 /* the following two calls return and take a GList of
    EVCardAttribute*'s. */
