@@ -1393,7 +1393,7 @@ initialize_backend (ECalBackendCalDAV *cbdav)
 	} 
 		
 	if (priv->cache == NULL) {
-		priv->cache = e_cal_backend_cache_new (priv->uri);
+		priv->cache = e_cal_backend_cache_new (priv->uri, E_CAL_SOURCE_TYPE_EVENT);
 
 		if (priv->cache == NULL) {
 			result = GNOME_Evolution_Calendar_OtherError;
@@ -1869,7 +1869,7 @@ process_object (ECalBackendCalDAV   *cbdav,
 				etag = e_cal_component_get_etag (ccomp);
 				
 				object.href  = g_strdup (href);
-				object.etag  = g_strdup (href);
+				object.etag  = g_strdup (etag);
 
 			} else {
 				object.href = e_cal_component_gen_href (ecomp, priv->uri);
@@ -1931,7 +1931,7 @@ process_object (ECalBackendCalDAV   *cbdav,
 				etag = e_cal_component_get_etag (ccomp);
 				
 				object.href  = g_strdup (href);
-				object.etag  = g_strdup (href);
+				object.etag  = g_strdup (etag);
 				object.cdata = NULL;
 
 				status = caldav_server_delete_object (cbdav,
@@ -2171,9 +2171,9 @@ caldav_add_timezone (ECalBackendSync *backend,
 }
 
 static ECalBackendSyncStatus
-caldav_set_default_timezone (ECalBackendSync *backend, 
+caldav_set_default_zone (ECalBackendSync *backend, 
 			     EDataCal        *cal,
-			     const char      *tzid)
+			     const char      *tzobj)
 {
 	/* FIXME: implement me! */
 	g_warning ("function not implemented %s", G_STRFUNC);
@@ -2536,7 +2536,7 @@ e_cal_backend_caldav_class_init (ECalBackendCalDAVClass *class)
 	sync_class->get_object_list_sync      = caldav_get_object_list;
 	sync_class->get_timezone_sync         = caldav_get_timezone;
 	sync_class->add_timezone_sync         = caldav_add_timezone;
-	sync_class->set_default_timezone_sync = caldav_set_default_timezone;
+	sync_class->set_default_zone_sync = caldav_set_default_zone;
 	sync_class->get_freebusy_sync         = caldav_get_free_busy;
 	sync_class->get_changes_sync          = caldav_get_changes;
 
